.. _strafbaar:


.. raw:: html

    <br>
    <center>

strafbaar
=========

.. raw:: html

    </center>
    <br>


De voorwaarden voor het bestaan van een strafbaar feit zijn:

1) menselijke gedraging/gedraging (commissie: doen of omissie: nalaten)

   het verschaffen van een wettelijk voorschrift dat gebruikt word om
   straffeloosheid te zekeren voor het plegen van een strafbaar feit in dit
   geval het toedienen van gif.

2) die valt binnen de delictsomschrijving

   Doodslag gevolgd, vergezeld of voorafgegaan van een strafbaar feit en gepleegd met het oogmerk om de uitvoering van dat feit 
   voor te bereiden of gemakkelijk te maken, of om, bij betrapping op heter daad, aan zichzelf of andere deelnemers aan dat feit hetzij straffeloosheid hetzij 
   het bezit van het wederrechtelijk verkregene te verzekeren, wordt gestraft met levenslange gevangenisstraf of tijdelijke van ten hoogste dertig jaren of geldboete van de vijfde categorie.

3) is wederrechtelijk

   het plegen van het delict is in zich al wederrechtelijk

4) is aan schuld te wijten.

   men is voor het aannemen van deze wetten op hoogste gesteld dat de in de wet vermelde medicijnen in werkelijk gif betreffen.

De wettelijke schulduitsluitingsgronden zijn:

1) ontoerekeningsvatbaarheid (art. 39 Sr)

   een kamerlid is niet gek, zijn ggz patient wel.

2) psychische overmacht (art. 40 Sr)

   mischien onder druk toch voorgestemt

3) noodweerexces (art. 41 lid 2 Sr)

   voor de veiligheid van nederland kan men niet anders.

4) een onbevoegd gegeven ambtelijk bevel (art. 43 lid 2 Sr).

   ik neem aan dat het kamerlid onafhankelijk functioneert

De wettelijke rechtvaardigingsgronden zijn:

1) overmacht in de zin van noodtoestand (art. 40 Sr)

   in geval van nood gaat men over lijken

2) wettelijk voorschrift (art. 42 Sr)

   de in de wet genoemde "medicatie" betreft in werkelijkheid gif.

3) bevoegd gegeven ambtelijk bevel (art. 43 lid 1 Sr)

   kamerleden stemmen niet op bevel.

4) noodweer (art. 41 lid 1 Sr).

   denken dat gif onder dwang noodweer is voor gevaar is  
